Database persistence for workflow and step models.
Functions
- persist_
run - Persist run.
- persist_
step_ instance - Persists a
StepInstancestate change to the database, along with logs and outputs.
Database persistence for workflow and step models.
StepInstance state change to the database, along with logs and outputs.