pub async fn persist_step_instance(
instance: &StepInstance,
executor: &mut PgConnection,
) -> Result<()>Expand description
Persists a StepInstance state change to the database, along with logs and outputs.
pub async fn persist_step_instance(
instance: &StepInstance,
executor: &mut PgConnection,
) -> Result<()>Persists a StepInstance state change to the database, along with logs and outputs.