State markers for the typestate pattern
Structs
- Aborted
- State representing a step that has been aborted.
- Failed
- State representing a step that has failed.
- Failed
Ignored - State representing a step that failed but the failure was configured to be ignored.
- Packing
Sfs - State representing a step that is packing its state into the Stormchaser File System.
- Pending
- State representing a step that is waiting to be executed.
- Running
- State representing a step that is currently executing.
- Skipped
- State representing a step that has been skipped (e.g., due to unmet conditions).
- Succeeded
- State representing a step that has successfully completed.
- Unpacking
Sfs - State representing a step that is unpacking its state from the Stormchaser File System.
- Waiting
ForEvent - State representing a step that is waiting for an external event (e.g., Human-In-The-Loop approval).