State markers for the workflow typestate pattern
Structs
- Aborted
- State representing a workflow run that has been aborted.
- Failed
- State representing a workflow run that has failed.
- Queued
- State representing a workflow run that is queued and waiting for resolution.
- Resolving
- State representing a workflow run that is resolving its source repository and dependencies.
- Running
- State representing a workflow run that is currently executing.
- Start
Pending - State representing a workflow run that has been resolved and is pending start.
- Succeeded
- State representing a workflow run that has successfully completed.